@@ -25,10 +25,6 @@
 */
 
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "types.h"
 #include "nes6502.h"
 #include "dis6502.h"
