@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2018 the xine project
+ * Copyright (C) 2000-2009 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -31,8 +31,6 @@
 #include <unistd.h>
 #include <inttypes.h>
 
-#define LOG_MODULE "audio_none_out"
-
 #include <xine/xine_internal.h>
 #include <xine/xineutils.h>
 #include <xine/audio_out.h>
@@ -42,9 +40,9 @@
 #define AUDIO_NUM_FRAGMENTS     15
 #define AUDIO_FRAGMENT_SIZE   8192
 
-#define AON_GAP_TOLERANCE        AO_MAX_GAP
+#define GAP_TOLERANCE        AO_MAX_GAP
 
-typedef struct ao_none_driver_s {
+typedef struct none_driver_s {
 
   ao_driver_t    ao_driver;
 
@@ -60,20 +58,21 @@ typedef struct ao_none_driver_s {
 
   uint32_t       latency;
 
-} ao_none_driver_t;
+} none_driver_t;
 
 typedef struct {
   audio_driver_class_t  driver_class;
 
+  config_values_t      *config;
   xine_t               *xine;
-} ao_none_class_t;
+} none_class_t;
 
 /*
  * open the audio device for writing to
  */
 static int ao_none_open(ao_driver_t *this_gen, uint32_t bits, uint32_t rate, int mode)
 {
-  ao_none_driver_t *this = (ao_none_driver_t *) this_gen;
+  none_driver_t *this = (none_driver_t *) this_gen;
 
   xprintf (this->xine, XINE_VERBOSITY_DEBUG,
 	   "audio_none_out: ao_open bits=%d rate=%d, mode=%d\n", bits, rate, mode);
@@ -97,27 +96,25 @@ static int ao_none_open(ao_driver_t *this_gen, uint32_t bits, uint32_t rate, int
 
 static int ao_none_num_channels(ao_driver_t *this_gen)
 {
-  ao_none_driver_t *this = (ao_none_driver_t *) this_gen;
+  none_driver_t *this = (none_driver_t *) this_gen;
     return this->num_channels;
 }
 
 static int ao_none_bytes_per_frame(ao_driver_t *this_gen)
 {
-  ao_none_driver_t *this = (ao_none_driver_t *) this_gen;
+  none_driver_t *this = (none_driver_t *) this_gen;
   return this->bytes_per_frame;
 }
 
 static int ao_none_get_gap_tolerance (ao_driver_t *this_gen)
 {
-  (void)this_gen;
-  return AON_GAP_TOLERANCE;
+  return GAP_TOLERANCE;
 }
 
 static int ao_none_write(ao_driver_t *this_gen, int16_t *data,
                          uint32_t num_frames)
 {
-  ao_none_driver_t *this = (ao_none_driver_t *) this_gen;
-  (void)data;
+  none_driver_t *this = (none_driver_t *) this_gen;
 
   /* take some time to pretend we are doing something.
    * avoids burning cpu.
@@ -131,23 +128,21 @@ static int ao_none_write(ao_driver_t *this_gen, int16_t *data,
 
 static int ao_none_delay (ao_driver_t *this_gen)
 {
-  (void)this_gen;
   return 0;
 }
 
 static void ao_none_close(ao_driver_t *this_gen)
 {
-  (void)this_gen;
 }
 
 static uint32_t ao_none_get_capabilities (ao_driver_t *this_gen) {
-  ao_none_driver_t *this = (ao_none_driver_t *) this_gen;
+  none_driver_t *this = (none_driver_t *) this_gen;
   return this->capabilities;
 }
 
 static void ao_none_exit(ao_driver_t *this_gen)
 {
-  ao_none_driver_t *this = (ao_none_driver_t *) this_gen;
+  none_driver_t *this = (none_driver_t *) this_gen;
 
   ao_none_close(this_gen);
 
@@ -156,22 +151,17 @@ static void ao_none_exit(ao_driver_t *this_gen)
 
 static int ao_none_get_property (ao_driver_t *this_gen, int property) {
 
-  (void)this_gen;
-  (void)property;
   return 0;
 }
 
 static int ao_none_set_property (ao_driver_t *this_gen, int property, int value) {
 
-  (void)this_gen;
-  (void)property;
   return ~value;
 }
 
 static int ao_none_ctrl(ao_driver_t *this_gen, int cmd, ...) {
-  /*ao_none_driver_t *this = (ao_none_driver_t *) this_gen;*/
+  /*none_driver_t *this = (none_driver_t *) this_gen;*/
 
-  (void)this_gen;
   switch (cmd) {
 
   case AO_CTRL_PLAY_PAUSE:
@@ -187,16 +177,16 @@ static int ao_none_ctrl(ao_driver_t *this_gen, int cmd, ...) {
   return 0;
 }
 
-static ao_driver_t *ao_none_open_plugin (audio_driver_class_t *class_gen,
+static ao_driver_t *open_plugin (audio_driver_class_t *class_gen,
 				 const void *data) {
 
-  ao_none_class_t     *class = (ao_none_class_t *) class_gen;
-  ao_none_driver_t    *this;
+  none_class_t     *class = (none_class_t *) class_gen;
+  /* config_values_t *config = class->config; */
+  none_driver_t    *this;
 
   lprintf ("open_plugin called\n");
 
-  (void)data;
-  this = calloc(1, sizeof (ao_none_driver_t));
+  this = calloc(1, sizeof (none_driver_t));
   if (!this)
     return NULL;
 
@@ -224,41 +214,38 @@ static ao_driver_t *ao_none_open_plugin (audio_driver_class_t *class_gen,
 /*
  * class functions
  */
-static void *ao_none_init_class (xine_t *xine, const void *data) {
+static void *init_class (xine_t *xine, void *data) {
 
-  ao_none_class_t        *this;
+  none_class_t        *this;
 
   lprintf ("init class\n");
 
-  (void)data;
-  this = calloc(1, sizeof (ao_none_class_t));
+  this = calloc(1, sizeof (none_class_t));
   if (!this)
     return NULL;
 
-  this->driver_class.open_plugin     = ao_none_open_plugin;
+  this->driver_class.open_plugin     = open_plugin;
   this->driver_class.identifier      = "none";
   this->driver_class.description     = N_("xine dummy audio output plugin");
   this->driver_class.dispose         = default_audio_driver_class_dispose;
 
+  this->config = xine->config;
   this->xine   = xine;
 
   return this;
 }
 
 static const ao_info_t ao_info_none = {
-  .priority = -1, /* do not auto probe this one */
+  -1 /* do not auto probe this one */
 };
 
 /*
  * exported plugin catalog entry
  */
 
-#define AO_NONE_CATALOG { PLUGIN_AUDIO_OUT, AO_OUT_NONE_IFACE_VERSION, "none", XINE_VERSION_CODE, &ao_info_none, ao_none_init_class }
-
-#ifndef XINE_MAKE_BUILTINS
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
-  AO_NONE_CATALOG,
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_AUDIO_OUT, AO_OUT_NONE_IFACE_VERSION, "none", XINE_VERSION_CODE, &ao_info_none, init_class },
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
-#endif
+
