@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2020 the xine project
+ * Copyright (C) 2013 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -22,8 +22,6 @@
 #include <xine/os_types.h>
 #include <xine/attributes.h>
 
-void *vorbis_init_plugin (xine_t *xine, const void *data);
-void *speex_init_plugin (xine_t *xine, const void *data);
-void *theora_init_plugin (xine_t *xine, const void *data);
-void *anx_init_class (xine_t *xine, const void *data);
-void *ogg_init_class (xine_t *xine, const void *data);
+void *vorbis_init_plugin (xine_t *xine, void *data);
+void *speex_init_plugin (xine_t *xine, void *data);
+void *theora_init_plugin (xine_t *xine, void *data);
