@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2017 the xine project
+ * Copyright (C) 2000-2014 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -41,20 +41,16 @@
 ebml_parser_t *new_ebml_parser (xine_t *xine, input_plugin_t *input) {
   ebml_parser_t *ebml;
 
-  ebml = calloc(1, sizeof(ebml_parser_t));
-  if (ebml) {
-    ebml->xine                 = xine;
-    ebml->input                = input;
-  }
+  ebml = xine_xmalloc(sizeof(ebml_parser_t));
+  ebml->xine                 = xine;
+  ebml->input                = input;
+
   return ebml;
 }
 
 
 void dispose_ebml_parser(ebml_parser_t *ebml) {
-  if (ebml) {
-    _x_freep(&ebml->doctype);
-    free(ebml);
-  }
+  free(ebml);
 }
 
 
@@ -63,9 +59,7 @@ uint32_t ebml_get_next_level(ebml_parser_t *ebml, ebml_elem_t *elem) {
 
   if (ebml->level > 0) {
     parent_elem = &ebml->elem_stack[ebml->level - 1];
-    while (/* avoid overflows with undefined len (=UINT64_MAX) */
-           /* (elem->start + elem->len) >= (parent_elem->start + parent_elem->len) */
-           (elem->start - parent_elem->start + elem->len) >= parent_elem->len) {
+    while ((elem->start + elem->len) >= (parent_elem->start + parent_elem->len)) {
       lprintf("parent: %" PRIdMAX ", %" PRIu64 "; elem: %" PRIdMAX  ", %" PRIu64 "\n",
               (intmax_t)parent_elem->start, parent_elem->len, (intmax_t)elem->start, elem->len);
       ebml->level--;
@@ -475,8 +469,7 @@ int ebml_check_header(ebml_parser_t *ebml) {
       default:
         xprintf(ebml->xine, XINE_VERBOSITY_LOG,
                 "ebml: Unknown data type 0x%x in EBML header (ignored)\n", elem.id);
-        if (!ebml_skip(ebml, &elem))
-          return 0;
+	ebml_skip(ebml, &elem);
     }
     next_level = ebml_get_next_level(ebml, &elem);
   }
