@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2018 the xine project
+ * Copyright (C) 2003-2014 the xine project
  * Copyright (C) 2003 J.Asselman <j.asselman@itsec-ps.nl>
  *
  * This file is part of xine, a free video player.
@@ -126,6 +126,11 @@ static const int tv_standard_values[] = { VIDEO_MODE_AUTO, VIDEO_MODE_PAL, VIDEO
 
 typedef struct pvrscr_s pvrscr_t;
 
+typedef struct {
+  input_class_t            input_class;
+  xine_t                  *xine;
+} v4l_input_class_t;
+
 typedef struct {
   input_plugin_t           input_plugin;
 
@@ -256,7 +261,6 @@ struct pvrscr_s {
 
 static int pvrscr_get_priority(scr_plugin_t *scr)
 {
-  (void)scr;
   return 10; /* high priority */
 }
 
@@ -519,12 +523,12 @@ static void store_vid_frame (buf_element_t *frame)
   pthread_mutex_unlock (&this->vid_frames_lock);
 }
 
-static int extract_mrl(v4l_input_plugin_t *this, const char *mrl)
+static int extract_mrl(v4l_input_plugin_t *this, char *mrl)
 {
   char   *tuner_name = NULL;
   int     frequency  = 0;
-  const char   *locator    = NULL;
-  const char   *begin      = NULL;
+  char   *locator    = NULL;
+  char   *begin      = NULL;
 
   if (mrl == NULL) {
     lprintf("Someone passed an empty mrl\n");
@@ -1244,9 +1248,6 @@ static int v4l_adjust_realtime_speed(v4l_input_plugin_t *this, fifo_buffer_t *fi
  */
 static off_t v4l_plugin_read (input_plugin_t *this_gen, void *buf, off_t len) {
   lprintf("Read not supported\n");
-  (void)this_gen;
-  (void)buf;
-  (void)len;
   return 0;
 }
 
@@ -1275,9 +1276,6 @@ static buf_element_t *v4l_plugin_read_block (input_plugin_t *this_gen, fifo_buff
   static char           video = 0;
   int                   speed = _x_get_speed(this->stream);
 
-#ifndef LOG
-  (void)todo;
-#endif
   v4l_event_handler(this);
 
 #ifdef HAVE_ALSA
@@ -1305,7 +1303,6 @@ static buf_element_t *v4l_plugin_read_block (input_plugin_t *this_gen, fifo_buff
 
     lprintf("sending video header");
 
-    memset(&bih, 0, sizeof(bih));
     bih.biSize   = sizeof(xine_bmiheader);
     bih.biWidth  = this->resolution->width;
     bih.biHeight = this->resolution->height;
@@ -1455,11 +1452,6 @@ static buf_element_t *v4l_plugin_read_block (input_plugin_t *this_gen, fifo_buff
 static off_t v4l_plugin_seek (input_plugin_t *this_gen, off_t offset, int origin) {
   v4l_input_plugin_t *this = (v4l_input_plugin_t *) this_gen;
 
-  (void)this_gen;
-#ifndef LOG
-  (void)offset;
-  (void)origin;
-#endif
   lprintf("seek %lld bytes, origin %d\n", offset, origin);
   return this->curpos;
 }
@@ -1474,7 +1466,6 @@ static off_t v4l_plugin_get_length (input_plugin_t *this_gen) {
     off_t                 length;
   */
 
-  (void)this_gen;
   return -1;
 }
 
@@ -1498,7 +1489,6 @@ static uint32_t v4l_plugin_get_capabilities (input_plugin_t *this_gen)
  */
 static uint32_t v4l_plugin_get_blocksize (input_plugin_t *this_gen)
 {
-  (void)this_gen;
   return 0;
 }
 
@@ -1667,9 +1657,6 @@ static int v4l_plugin_get_optional_data (input_plugin_t *this_gen,
                                          void *data, int data_type) {
   /* v4l_input_plugin_t *this = (v4l_input_plugin_t *) this_gen; */
 
-  (void)this_gen;
-  (void)data;
-  (void)data_type;
   return INPUT_OPTIONAL_UNSUPPORTED;
 }
 
@@ -1738,18 +1725,20 @@ static input_plugin_t *v4l_class_get_instance (input_class_t *cls_gen,
 #ifdef HAVE_ALSA
   cfg_entry_t        *entry;
 #endif
+  char               *mrl     = strdup(data);
 
   /* Example mrl:  v4l:/Television/62500 */
-  if(!data || strncasecmp(data, "v4l:/", 5)) {
+  if(!mrl || strncasecmp(mrl, "v4l:/", 5)) {
+    free(mrl);
     return NULL;
   }
 
   this = calloc(1, sizeof (v4l_input_plugin_t));
-  if (!this)
-    return NULL;
+
+  extract_mrl(this, mrl);
 
   this->stream        = stream;
-  this->mrl           = strdup(data);
+  this->mrl           = mrl;
   this->video_buf     = NULL;
   this->video_fd      = -1;
   this->radio_fd      = -1;
@@ -1759,8 +1748,6 @@ static input_plugin_t *v4l_class_get_instance (input_class_t *cls_gen,
   this->pcm_data      = NULL;
   this->pcm_hwparams  = NULL;
 
-  extract_mrl(this, this->mrl);
-
   /* Audio */
   this->pcm_stream    = SND_PCM_STREAM_CAPTURE;
   entry = this->stream->xine->config->lookup_entry(this->stream->xine->config,
@@ -1907,20 +1894,23 @@ static input_plugin_t *v4l_class_get_radio_instance (input_class_t *cls_gen,
 /*
  * v4l input plugin class stuff
  */
-static void *init_video_class (xine_t *xine, const void *data)
+static void *init_video_class (xine_t *xine, void *data)
 {
-  static const input_class_t v4l_video_input_class = {
-    .get_instance       = v4l_class_get_video_instance,
-    .identifier         = "v4l",
-    .description        = N_("v4l tv input plugin"),
-    .get_dir            = NULL,
-    .get_autoplay_list  = NULL,
-    .dispose            = NULL,
-    .eject_media        = NULL,
-  };
-
+  v4l_input_class_t  *this;
   config_values_t    *config = xine->config;
 
+  this = calloc(1, sizeof (v4l_input_class_t));
+
+  this->xine                           = xine;
+
+  this->input_class.get_instance       = v4l_class_get_video_instance;
+  this->input_class.identifier         = "v4l";
+  this->input_class.description        = N_("v4l tv input plugin");
+  this->input_class.get_dir            = NULL;
+  this->input_class.get_autoplay_list  = NULL;
+  this->input_class.dispose            = default_input_class_dispose;
+  this->input_class.eject_media        = NULL;
+
   config->register_filename (config, "media.video4linux.video_device",
 			   VIDEO_DEV, XINE_CONFIG_STRING_IS_DEVICE_NAME,
 			   _("v4l video device"),
@@ -1939,23 +1929,25 @@ static void *init_video_class (xine_t *xine, const void *data)
                         _("Selects the TV standard of the input signals. "
                         "Either: AUTO, PAL, NTSC or SECAM. "), 20, NULL, NULL);
 
-  (void)data;
-  return (void *)&v4l_video_input_class;
+  return this;
 }
 
-static void *init_radio_class (xine_t *xine, const void *data)
+static void *init_radio_class (xine_t *xine, void *data)
 {
-  static const input_class_t v4l_radio_input_class = {
-    .get_instance       = v4l_class_get_radio_instance,
-    .identifier         = "v4l",
-    .description        = N_("v4l radio input plugin"),
-    .get_dir            = NULL,
-    .get_autoplay_list  = NULL,
-    .dispose            = NULL,
-    .eject_media        = NULL,
-  };
+  v4l_input_class_t  *this;
+  config_values_t    *config = xine->config;
 
-  config_values_t *config = xine->config;
+  this = calloc(1, sizeof (v4l_input_class_t));
+
+  this->xine                           = xine;
+
+  this->input_class.get_instance       = v4l_class_get_radio_instance;
+  this->input_class.identifier         = "v4l";
+  this->input_class.description        = N_("v4l radio input plugin");
+  this->input_class.get_dir            = NULL;
+  this->input_class.get_autoplay_list  = NULL;
+  this->input_class.dispose            = default_input_class_dispose;
+  this->input_class.eject_media        = NULL;
 
   config->register_filename (config, "media.video4linux.radio_device",
 			   RADIO_DEV, XINE_CONFIG_STRING_IS_DEVICE_NAME,
@@ -1963,8 +1955,7 @@ static void *init_radio_class (xine_t *xine, const void *data)
 			   _("The path to your Video4Linux radio device."),
 			   10, NULL, NULL);
 
-  (void)data;
-  return (void *)&v4l_radio_input_class;
+  return this;
 }
 
 /*
@@ -1975,7 +1966,7 @@ const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_INPUT | PLUGIN_MUST_PRELOAD, 18, "v4l_radio", XINE_VERSION_CODE, NULL, init_radio_class },
   { PLUGIN_INPUT | PLUGIN_MUST_PRELOAD, 18, "v4l_tv", XINE_VERSION_CODE, NULL, init_video_class },
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
 /*
