@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2019 the xine project
+ * Copyright (C) 2002-2009 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -30,20 +30,24 @@
 #include "config.h"
 #endif
 
+#include <unistd.h>
 #include <stdio.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <netdb.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <errno.h>
 #include <stdlib.h>
+#include <time.h>
 
 #if defined(HAVE_ICONV) && defined(HAVE_NL_LANGINFO)
 #define USE_ICONV
 #include <iconv.h>
 #include <locale.h>
 #include <langinfo.h>
-#else
-# ifndef ICONV_CONST
-#   define ICONV_CONST const
-# endif
 #endif
 
 /********** logging **********/
@@ -107,7 +111,13 @@ struct mms_s {
   int           s;
 
   /* url parsing */
-  xine_url_t    url;
+  char         *url;
+  char         *proto;
+  char         *host;
+  int           port;
+  char         *user;
+  char         *password;
+  char         *uri;
 
   /* command to send */
   char          scmd[CMD_HEADER_LEN + CMD_BODY_LEN];
@@ -526,7 +536,7 @@ static int interp_asf_header (mms_t *this) {
 
 static const char mmst_proto_s[][8] = { "mms", "mmst", "" };
 
-static int mmst_valid_proto (const char *proto) {
+static int mmst_valid_proto (char *proto) {
   int i = 0;
 
   lprintf("mmst_valid_proto\n");
@@ -565,17 +575,16 @@ static void report_progress (xine_stream_t *stream, int p) {
 static int mms_tcp_connect(mms_t *this) {
   int progress, res;
 
-  if (!this->url.port)
-    this->url.port = MMST_PORT;
+  if (!this->port) this->port = MMST_PORT;
 
   /*
    * try to connect
    */
-  lprintf("try to connect to %s on port %d \n", this->url.host, this->url.port);
-  this->s = _x_io_tcp_connect (this->stream, this->url.host, this->url.port);
-  if (this->s < 0) {
+  lprintf("try to connect to %s on port %d \n", this->host, this->port);
+  this->s = _x_io_tcp_connect (this->stream, this->host, this->port);
+  if (this->s == -1) {
     xprintf (this->stream->xine, XINE_VERBOSITY_LOG,
-             "failed to connect '%s'\n", this->url.host);
+             "failed to connect '%s'\n", this->host);
     return 1;
   }
 
@@ -660,7 +669,7 @@ static int mms_choose_best_streams(mms_t *this) {
  */
 mms_t *mms_connect (xine_stream_t *stream, const char *url, int bandwidth) {
 #ifdef USE_ICONV
-  iconv_t url_conv = (iconv_t)-1;
+  iconv_t url_conv;
 #else
   int     url_conv = 0;
 #endif
@@ -674,6 +683,7 @@ mms_t *mms_connect (xine_stream_t *stream, const char *url, int bandwidth) {
   this = calloc(1, sizeof (mms_t));
 
   this->stream          = stream;
+  this->url             = strdup (url);
   this->s               = -1;
   this->seq_num         = 0;
   this->scmd_body       = this->scmd + CMD_HEADER_LEN + CMD_PREFIX_LEN;
@@ -687,12 +697,13 @@ mms_t *mms_connect (xine_stream_t *stream, const char *url, int bandwidth) {
 
   report_progress (stream, 0);
 
-  if (!_x_url_parse2 (url, &this->url)) {
+  if (!_x_parse_url (this->url, &this->proto, &this->host, &this->port,
+                     &this->user, &this->password, &this->uri, NULL)) {
     lprintf ("invalid url\n");
     goto fail;
   }
 
-  if (!mmst_valid_proto(this->url.proto)) {
+  if (!mmst_valid_proto(this->proto)) {
     lprintf ("unsupported protocol\n");
     goto fail;
   }
@@ -713,7 +724,7 @@ mms_t *mms_connect (xine_stream_t *stream, const char *url, int bandwidth) {
   lprintf("send command 0x01\n");
   mms_gen_guid(this->guid);
   snprintf (str, sizeof(str), "\x1c\x03NSPlayer/7.0.0.1956; {%s}; Host: %s",
-    this->guid, this->url.host);
+    this->guid, this->host);
   string_utf16 (url_conv, this->scmd_body, str, strlen(str) + 2);
 
   if (!send_command (this, 1, 0, 0x0004000b, strlen(str) * 2 + 8)) {
@@ -763,7 +774,7 @@ mms_t *mms_connect (xine_stream_t *stream, const char *url, int bandwidth) {
     char *path, *unescaped;
     size_t pathlen;
 
-    unescaped = strdup (this->url.uri);
+    unescaped = strdup (this->uri);
     if (!unescaped)
       goto fail;
     _x_mrl_unescape (unescaped);
@@ -891,14 +902,20 @@ mms_t *mms_connect (xine_stream_t *stream, const char *url, int bandwidth) {
   return this;
 
 fail:
-#ifdef USE_ICONV
-  string_utf16_close(url_conv);
-#endif
-
   if (this->s != -1)
-    _x_io_tcp_close (this->stream, this->s);
-
-  _x_url_cleanup(&this->url);
+    close (this->s);
+  if (this->url)
+    free(this->url);
+  if (this->proto)
+    free(this->proto);
+  if (this->host)
+    free(this->host);
+  if (this->user)
+    free(this->user);
+  if (this->password)
+    free(this->password);
+  if (this->uri)
+    free(this->uri);
 
   free (this);
   return NULL;
@@ -1126,10 +1143,19 @@ int mms_read (mms_t *this, char *data, int len) {
 void mms_close (mms_t *this) {
 
   if (this->s != -1)
-    _x_io_tcp_close (this->stream, this->s);
-
-  _x_url_cleanup(&this->url);
-
+    close (this->s);
+  if (this->url)
+    free(this->url);
+  if (this->proto)
+    free(this->proto);
+  if (this->host)
+    free(this->host);
+  if (this->user)
+    free(this->user);
+  if (this->password)
+    free(this->password);
+  if (this->uri)
+    free(this->uri);
   if (this->asf_header)
     asf_header_delete(this->asf_header);
   free (this);
