@@ -85,7 +85,7 @@
 **   B0    |         |    B1   |         |
 */
 
-#if defined(ARCH_X86)
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
 static const sse_t Mask128 = { uq: { 0x7f7f7f7f7f7f7f7fll, 0x7f7f7f7f7f7f7f7fll} };
 #define TP GREEDYTWOFRAMETHRESHOLD, GREEDYTWOFRAMETHRESHOLD2
 static const sse_t GreedyTwoFrameThreshold128 = { ub: {TP, TP, TP, TP, TP, TP, TP, TP} };
@@ -97,7 +97,7 @@ static void DeinterlaceGreedy2Frame_SSE2(uint8_t *output, int outstride,
                                          int bottom_field, int second_field,
                                          int width, int height )
 {
-#if defined(ARCH_X86)
+#if defined(ARCH_X86) || defined(ARCH_X86_64)
     int Line;
     int stride = width * 2;
     register uint8_t* M1;
@@ -158,7 +158,7 @@ static void DeinterlaceGreedy2Frame_SSE2(uint8_t *output, int outstride,
 
         /* just rely on gcc not using xmm regs... */
         do {
-          __asm__ __volatile__(
+          asm volatile(
             "movdqa  %0, %%xmm6			\n\t"     // xmm6 = Mask
             "pxor    %%xmm7, %%xmm7		\n\t"     // xmm7 = zero
             : /* no output */
@@ -167,15 +167,15 @@ static void DeinterlaceGreedy2Frame_SSE2(uint8_t *output, int outstride,
 
         count = LineLength >> 4;
         do {
-          __asm__ __volatile__(
+          asm volatile(
        /* Figure out what to do with the scanline above the one we copy.
         * See above for a description of the algorithm.
         * weave if (weave(M) AND (weave(T) OR weave(B)))
         */
             "movdqa  (%2), %%xmm1		\n\t" /* xmm1 = T1 */
             "movdqa  (%3), %%xmm0		\n\t" /* xmm0 = T0 */
-            "movdqa  (%4,%2), %%xmm3		\n\t" /* xmm3 = B1 */
-            "movdqa  (%4,%3), %%xmm2		\n\t" /* xmm2 = B0 */
+            "movdqa  (%q4,%2), %%xmm3		\n\t" /* xmm3 = B1 */
+            "movdqa  (%q4,%3), %%xmm2		\n\t" /* xmm2 = B0 */
 
             /* calculate |T1-T0| keep T1 put result in xmm5 */
             "movdqa  %%xmm1, %%xmm5		\n\t"
@@ -192,13 +192,13 @@ static void DeinterlaceGreedy2Frame_SSE2(uint8_t *output, int outstride,
             "pcmpgtb %0, %%xmm5			\n\t"
             "pcmpeqd %%xmm7, %%xmm5		\n\t"
 
-            "prefetcht0  64(%4,%2)		\n\t"
-            "prefetcht0  64(%4,%3)		\n\t"
+            "prefetcht0  64(%q4,%2)		\n\t"
+            "prefetcht0  64(%q4,%3)		\n\t"
           :
           : "m" (GreedyTwoFrameThreshold128),
-            "m" (*Destc), "r" (T1), "r" (T0), "r" ((void*)(intptr_t)Pitch) );
+            "m" (*Destc), "r" (T1), "r" (T0), "r" (Pitch) );
 
-          __asm__ __volatile__ (
+          asm volatile (
             /* calculate |B1-B0| keep B1 put result in xmm4 */
             "movdqa  %%xmm3, %%xmm4		\n\t"
             "psubusb %%xmm2, %%xmm4		\n\t"
@@ -277,7 +277,7 @@ static void DeinterlaceGreedy2Frame_SSE2(uint8_t *output, int outstride,
         T0 += PitchRest;
     }
 
-    __asm__ __volatile__("sfence\n\t");
+    asm("sfence\n\t");
 
     if( bottom_field )
     {
