@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2018 the xine project
+ * Copyright (C) 2000-2009 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -293,11 +293,9 @@ static void spudec_decode_data (spu_decoder_t *this_gen, buf_element_t *buf) {
 }
 
 static void spudec_reset (spu_decoder_t *this_gen) {
-  (void)this_gen;
 }
 
 static void spudec_discontinuity (spu_decoder_t *this_gen) {
-  (void)this_gen;
 }
 
 static void spudec_dispose (spu_decoder_t *this_gen) {
@@ -314,8 +312,6 @@ static spu_decoder_t *spudec_open_plugin (spu_decoder_class_t *class, xine_strea
   spucc_decoder_t *this ;
 
   this = (spucc_decoder_t *) calloc(1, sizeof(spucc_decoder_t));
-  if (!this)
-    return NULL;
 
   this->spu_decoder.decode_data         = spudec_decode_data;
   this->spu_decoder.reset               = spudec_reset;
@@ -333,14 +329,11 @@ static spu_decoder_t *spudec_open_plugin (spu_decoder_class_t *class, xine_strea
   return &this->spu_decoder;
 }
 
-static void *init_spu_decoder_plugin (xine_t *xine, const void *data) {
+static void *init_spu_decoder_plugin (xine_t *xine, void *data) {
 
   spucc_class_t *this ;
 
-  (void)data;
   this = (spucc_class_t *) calloc(1, sizeof(spucc_class_t));
-  if (!this)
-    return NULL;
 
   this->spu_class.open_plugin      = spudec_open_plugin;
   this->spu_class.identifier       = "spucc";
@@ -357,12 +350,12 @@ static void *init_spu_decoder_plugin (xine_t *xine, const void *data) {
 static const uint32_t supported_types[] = { BUF_SPU_CC, 0 };
 
 static const decoder_info_t spudec_info = {
-  .supported_types = supported_types,
-  .priority        = 1,
+  supported_types,     /* supported types */
+  1                    /* priority        */
 };
 
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_SPU_DECODER, 17, "spucc", XINE_VERSION_CODE, &spudec_info, &init_spu_decoder_plugin },
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
