@@ -20,10 +20,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <xine/xine_internal.h>
 #include "mpeg2.h"
 #include "mpeg2_internal.h"
@@ -34,9 +30,6 @@
 void 
 libmpeg2_accel_scan( mpeg2dec_accel_t *accel, uint8_t *scan_norm, uint8_t *scan_alt)
 {
-  (void)accel;
-  (void)scan_norm;
-  (void)scan_alt;
   xvmc_setup_scan_ptable();
 }
 
@@ -66,7 +59,6 @@ libmpeg2_accel_discontinuity(mpeg2dec_accel_t *accel, uint32_t frame_format, pic
 int 
 libmpeg2_accel_new_sequence(mpeg2dec_accel_t *accel, uint32_t frame_format, picture_t *picture)
 {
-  (void)accel;
   switch(frame_format) {
   case XINE_IMGFMT_XXMC:
   case XINE_IMGFMT_XVMC: {
@@ -85,7 +77,6 @@ int
 libmpeg2_accel_new_frame(mpeg2dec_accel_t *accel, uint32_t frame_format, 
 			 picture_t *picture, double ratio, uint32_t flags)
 {  
-  (void)accel;
   if (picture->current_frame) {
     if (XINE_IMGFMT_XXMC == frame_format) {
       xine_xxmc_t *xxmc = (xine_xxmc_t *) 
