@@ -1,6 +1,6 @@
 /*
  * kate: space-indent on; indent-width 2; mixedindent off; indent-mode cstyle; remove-trailing-space on;
- * Copyright (C) 2008-2020 the xine project
+ * Copyright (C) 2008-2013 the xine project
  * Copyright (C) 2008 Christophe Thommeret <hftom@free.fr>
  *
  * This file is part of xine, a free video player.
@@ -42,7 +42,6 @@
 #include <xine/xineutils.h>
 #include "accel_vdpau.h"
 #include "bits_reader.h"
-#include "group_vdpau.h"
 
 #include <vdpau/vdpau.h>
 
@@ -172,9 +171,17 @@ typedef struct {
 } sequence_t;
 
 
+
+typedef struct {
+  video_decoder_class_t   decoder_class;
+} vdpau_mpeg12_class_t;
+
+
+
 typedef struct vdpau_mpeg12_decoder_s {
   video_decoder_t         video_decoder;  /* parent video decoder structure */
 
+  vdpau_mpeg12_class_t    *class;
   xine_stream_t           *stream;
 
   sequence_t              sequence;
@@ -351,21 +358,21 @@ static void process_sequence_mpeg12_dependent_data( vdpau_mpeg12_decoder_t *this
     double pel_aspect_ratio; /* height / width */
 
     switch ( sequence->aspect_ratio_information ) {
-      case  1: pel_aspect_ratio = 1.0000; break;
-      case  2: pel_aspect_ratio = 0.6735; break;
-      case  3: pel_aspect_ratio = 0.7031; break;
-      case  4: pel_aspect_ratio = 0.7615; break;
-      case  5: pel_aspect_ratio = 0.8055; break;
-      case  6: pel_aspect_ratio = 0.8437; break;
-      case  7: pel_aspect_ratio = 0.8935; break;
-      case  8: pel_aspect_ratio = 0.9157; break;
-      case  9: pel_aspect_ratio = 0.9815; break;
-      case 10: pel_aspect_ratio = 1.0255; break;
-      case 11: pel_aspect_ratio = 1.0695; break;
-      case 12: pel_aspect_ratio = 1.0950; break;
-      case 13: pel_aspect_ratio = 1.1575; break;
-      case 14: pel_aspect_ratio = 1.2015; break;
-      default: pel_aspect_ratio = 1.0000; /* fallback */ break;
+      case  1: pel_aspect_ratio = 1.0000;
+      case  2: pel_aspect_ratio = 0.6735;
+      case  3: pel_aspect_ratio = 0.7031;
+      case  4: pel_aspect_ratio = 0.7615;
+      case  5: pel_aspect_ratio = 0.8055;
+      case  6: pel_aspect_ratio = 0.8437;
+      case  7: pel_aspect_ratio = 0.8935;
+      case  8: pel_aspect_ratio = 0.9157;
+      case  9: pel_aspect_ratio = 0.9815;
+      case 10: pel_aspect_ratio = 1.0255;
+      case 11: pel_aspect_ratio = 1.0695;
+      case 12: pel_aspect_ratio = 1.0950;
+      case 13: pel_aspect_ratio = 1.1575;
+      case 14: pel_aspect_ratio = 1.2015;
+      default: pel_aspect_ratio = 1.0000; /* fallback */
     }
 
     sequence->ratio = ((double)sequence->coded_width/(double)sequence->coded_height)/pel_aspect_ratio;
@@ -685,15 +692,11 @@ static void decode_render( vdpau_mpeg12_decoder_t *vd, vdpau_accel_t *accel )
 
   VdpStatus st;
   if ( vd->decoder==VDP_INVALID_HANDLE || vd->decoder_profile!=seq->profile || vd->decoder_width!=seq->coded_width || vd->decoder_height!=seq->coded_height ) {
-    if (accel->lock)
-      accel->lock (accel->vo_frame);
     if ( vd->decoder!=VDP_INVALID_HANDLE ) {
       accel->vdp_decoder_destroy( vd->decoder );
       vd->decoder = VDP_INVALID_HANDLE;
     }
     st = accel->vdp_decoder_create( accel->vdp_device, seq->profile, seq->coded_width, seq->coded_height, 2, &vd->decoder);
-    if (accel->unlock)
-      accel->unlock (accel->vo_frame);
     if ( st!=VDP_STATUS_OK )
       lprintf( "failed to create decoder !! %s\n", accel->vdp_get_error_string( st ) );
     else {
@@ -708,16 +711,12 @@ static void decode_render( vdpau_mpeg12_decoder_t *vd, vdpau_accel_t *accel )
   vbit.struct_version = VDP_BITSTREAM_BUFFER_VERSION;
   vbit.bitstream = pic->slices;
   vbit.bitstream_bytes = (pic->vdp_infos.picture_structure==PICTURE_FRAME)? pic->slices_pos : pic->slices_pos_top;
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
-  st = accel->vdp_decoder_render( vd->decoder, accel->surface, CAST_VdpPictureInfo_PTR &pic->vdp_infos, 1, &vbit );
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
+  st = accel->vdp_decoder_render( vd->decoder, accel->surface, (VdpPictureInfo*)&pic->vdp_infos, 1, &vbit );
 #ifdef LOG
   if ( st!=VDP_STATUS_OK )
     lprintf( "decoder failed : %d!! %s\n", st, accel->vdp_get_error_string( st ) );
   else {
-    lprintf( "DECODER SUCCESS : frame_type:%d, slices=%d, slices_bytes=%d, current=%d, forwref:%d, backref:%d, pts:%"PRId64"\n",
+    lprintf( "DECODER SUCCESS : frame_type:%d, slices=%d, slices_bytes=%d, current=%d, forwref:%d, backref:%d, pts:%lld\n",
       pic->vdp_infos.picture_coding_type, pic->vdp_infos.slice_count, vbit.bitstream_bytes, accel->surface, pic->vdp_infos.forward_reference, pic->vdp_infos.backward_reference, seq->cur_pts );
     VdpPictureInfoMPEG1Or2 *info = &pic->vdp_infos;
     lprintf("%d %d %d %d %d %d %d %d %d %d %d %d %d\n", info->intra_dc_precision, info->frame_pred_frame_dct, info->concealment_motion_vectors,
@@ -742,15 +741,11 @@ static void decode_render( vdpau_mpeg12_decoder_t *vd, vdpau_accel_t *accel )
     vbit.struct_version = VDP_BITSTREAM_BUFFER_VERSION;
     vbit.bitstream = pic->slices+pic->slices_pos_top;
     vbit.bitstream_bytes = pic->slices_pos-pic->slices_pos_top;
-    if (accel->lock)
-      accel->lock (accel->vo_frame);
-    st = accel->vdp_decoder_render( vd->decoder, accel->surface, CAST_VdpPictureInfo_PTR &pic->vdp_infos2, 1, &vbit );
-    if (accel->unlock)
-      accel->unlock (accel->vo_frame);
+    st = accel->vdp_decoder_render( vd->decoder, accel->surface, (VdpPictureInfo*)&pic->vdp_infos2, 1, &vbit );
     if ( st!=VDP_STATUS_OK )
       lprintf( "decoder failed : %d!! %s\n", st, accel->vdp_get_error_string( st ) );
     else
-      lprintf( "DECODER SUCCESS : frame_type:%d, slices=%d, current=%d, forwref:%d, backref:%d, pts:%" PRId64 "\n",
+      lprintf( "DECODER SUCCESS : frame_type:%d, slices=%d, current=%d, forwref:%d, backref:%d, pts:%lld\n",
         pic->vdp_infos2.picture_coding_type, pic->vdp_infos2.slice_count, accel->surface, pic->vdp_infos2.forward_reference, pic->vdp_infos2.backward_reference, seq->cur_pts );
   }
 }
@@ -932,14 +927,14 @@ static void vdpau_mpeg12_decode_data (video_decoder_t *this_gen, buf_element_t *
     seq->cur_pts = buf->pts;
 
   int size = seq->bufpos+buf->size;
-  if ( seq->bufsize < (unsigned int)size ) {
+  if ( seq->bufsize < size ) {
     seq->bufsize = size+1024;
     seq->buf = realloc( seq->buf, seq->bufsize );
   }
   xine_fast_memcpy( seq->buf+seq->bufpos, buf->content, buf->size );
   seq->bufpos += buf->size;
 
-  while ( seq->bufseek <= (int)(seq->bufpos)-4 ) {
+  while ( seq->bufseek <= seq->bufpos-4 ) {
     uint8_t *buffer = seq->buf+seq->bufseek;
     if ( buffer[0]==0 && buffer[1]==0 && buffer[2]==1 ) {
       if ( seq->start<0 ) {
@@ -973,7 +968,6 @@ static void vdpau_mpeg12_decode_data (video_decoder_t *this_gen, buf_element_t *
 static void vdpau_mpeg12_flush (video_decoder_t *this_gen) {
 
   lprintf( "vdpau_mpeg12_flush\n" );
-  (void)this_gen;
 }
 
 /*
@@ -1006,12 +1000,8 @@ static void vdpau_mpeg12_dispose (video_decoder_t *this_gen) {
   lprintf( "vdpau_mpeg12_dispose\n" );
 
   if ( this->decoder!=VDP_INVALID_HANDLE && this->sequence.accel_vdpau ) {
-      if (this->sequence.accel_vdpau->lock)
-        this->sequence.accel_vdpau->lock (this->sequence.accel_vdpau->vo_frame);
       this->sequence.accel_vdpau->vdp_decoder_destroy( this->decoder );
       this->decoder = VDP_INVALID_HANDLE;
-      if (this->sequence.accel_vdpau->unlock)
-        this->sequence.accel_vdpau->unlock (this->sequence.accel_vdpau->vo_frame);
     }
 
   free_sequence( &this->sequence );
@@ -1033,41 +1023,25 @@ static video_decoder_t *open_plugin (video_decoder_class_t *class_gen, xine_stre
 
   lprintf( "open_plugin\n" );
 
-  (void)class_gen;
-
   /* the videoout must be vdpau-capable to support this decoder */
-  if ( !(stream->video_out->get_capabilities(stream->video_out) & VO_CAP_VDPAU_MPEG12) )
+  if ( !(stream->video_driver->get_capabilities(stream->video_driver) & VO_CAP_VDPAU_MPEG12) )
     return NULL;
 
   /* now check if vdpau has free decoder resource */
-  vo_frame_t *img = stream->video_out->get_frame( stream->video_out, 1920, 1080, 1, XINE_IMGFMT_VDPAU,
-                                                  VO_BOTH_FIELDS | VO_GET_FRAME_MAY_FAIL );
-  if (!img) {
-    return NULL;
-  }
+  vo_frame_t *img = stream->video_out->get_frame( stream->video_out, 1920, 1080, 1, XINE_IMGFMT_VDPAU, VO_BOTH_FIELDS );
   vdpau_accel_t *accel = (vdpau_accel_t*)img->accel_data;
   int runtime_nr = accel->vdp_runtime_nr;
   img->free(img);
   VdpDecoder decoder;
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
   VdpStatus st = accel->vdp_decoder_create( accel->vdp_device, VDP_DECODER_PROFILE_MPEG2_MAIN, 1920, 1080, 2, &decoder );
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
   if ( st!=VDP_STATUS_OK ) {
     lprintf( "can't create vdpau decoder.\n" );
     return NULL;
   }
 
-  if (accel->lock)
-    accel->lock (accel->vo_frame);
   accel->vdp_decoder_destroy( decoder );
-  if (accel->unlock)
-    accel->unlock (accel->vo_frame);
 
   this = (vdpau_mpeg12_decoder_t *) calloc(1, sizeof(vdpau_mpeg12_decoder_t));
-  if (!this)
-    return NULL;
 
   this->video_decoder.decode_data         = vdpau_mpeg12_decode_data;
   this->video_decoder.flush               = vdpau_mpeg12_flush;
@@ -1076,6 +1050,7 @@ static video_decoder_t *open_plugin (video_decoder_class_t *class_gen, xine_stre
   this->video_decoder.dispose             = vdpau_mpeg12_dispose;
 
   this->stream                            = stream;
+  this->class                             = (vdpau_mpeg12_class_t *) class_gen;
 
   this->sequence.bufsize = 1024;
   this->sequence.buf = (uint8_t*)malloc(this->sequence.bufsize);
@@ -1105,20 +1080,50 @@ static video_decoder_t *open_plugin (video_decoder_class_t *class_gen, xine_stre
  * This function allocates a private video decoder class and initializes
  * the class's member functions.
  */
-void *mpeg12_init_plugin (xine_t *xine, const void *data) {
+static void *init_plugin (xine_t *xine, void *data) {
 
-  (void)xine;
-  (void)data;
+  vdpau_mpeg12_class_t *this;
 
-  static const video_decoder_class_t decode_video_vdpau_mpeg12_class = {
-    .open_plugin     = open_plugin,
-    .identifier      = "vdpau_mpeg12",
-    .description     =
-        N_("vdpau_mpeg12: mpeg1/2 decoder plugin using VDPAU hardware decoding.\n"
-           "Must be used along with video_out_vdpau."),
-    .dispose         = NULL,
-  };
+  this = (vdpau_mpeg12_class_t *) calloc(1, sizeof(vdpau_mpeg12_class_t));
 
-  return (void *)&decode_video_vdpau_mpeg12_class;
+  this->decoder_class.open_plugin     = open_plugin;
+  this->decoder_class.identifier      = "vdpau_mpeg12";
+  this->decoder_class.description     =
+	N_("vdpau_mpeg12: mpeg1/2 decoder plugin using VDPAU hardware decoding.\n"
+	   "Must be used along with video_out_vdpau.");
+  this->decoder_class.dispose         = default_video_decoder_class_dispose;
+
+  return this;
 }
 
+/*
+ * This is a list of all of the internal xine video buffer types that
+ * this decoder is able to handle. Check src/xine-engine/buffer.h for a
+ * list of valid buffer types (and add a new one if the one you need does
+ * not exist). Terminate the list with a 0.
+ */
+static const uint32_t video_types[] = {
+  BUF_VIDEO_MPEG,
+  0
+};
+
+/*
+ * This data structure combines the list of supported xine buffer types and
+ * the priority that the plugin should be given with respect to other
+ * plugins that handle the same buffer type. A plugin with priority (n+1)
+ * will be used instead of a plugin with priority (n).
+ */
+static const decoder_info_t dec_info_video = {
+  video_types,         /* supported types */
+  8                    /* priority        */
+};
+
+/*
+ * The plugin catalog entry. This is the only information that this plugin
+ * will export to the public.
+ */
+const plugin_info_t xine_plugin_info[] EXPORTED = {
+  /* { type, API, "name", version, special_info, init_function } */
+  { PLUGIN_VIDEO_DECODER, 19, "vdpau_mpeg12", XINE_VERSION_CODE, &dec_info_video, init_plugin },
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
+};
