@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2020 the xine project and Claudio Ciccani
+ * Copyright (C) 2000-2011 the xine project and Claudio Ciccani
  *
  * This file is part of xine, a free video player.
  *
@@ -208,8 +208,6 @@ static uint32_t directfb_get_capabilities (vo_driver_t *this_gen) {
 
 static void directfb_frame_field (vo_frame_t *vo_img, int which_field) {
   /* not needed */
-  (void)vo_img;
-  (void)which_field;
 }
 
 static void directfb_frame_dispose (vo_frame_t *vo_img) {
@@ -256,18 +254,16 @@ static void directfb_update_frame_format (vo_driver_t *this_gen,
   directfb_frame_t      *frame  = (directfb_frame_t *) frame_gen;
   DFBSurfacePixelFormat  format = (fmt == XINE_IMGFMT_YUY2) ? DSPF_YUY2 : DSPF_YV12;
 
-  (void)flags;
-
   if (frame->surface == NULL   ||
-      frame->width   != (int)width  ||
-      frame->height  != (int)height ||
+      frame->width   != width  ||
+      frame->height  != height ||
       frame->format  != format)
   {
     DFBSurfaceDescription dsc;
     DFBResult             ret;
 
     lprintf ("frame %p: format changed to %dx%d %s.\n",
-             (void*)frame, width, height, (format == DSPF_YUY2) ? "YUY2" : "YV12");
+             frame, width, height, (format == DSPF_YUY2) ? "YUY2" : "YV12");
 
     if (frame->surface) {
       if (frame->locked)
@@ -585,8 +581,6 @@ static void directfb_overlay_blend (vo_driver_t *this_gen,
 static void directfb_overlay_end (vo_driver_t *this_gen, vo_frame_t *frame_gen) {
   directfb_driver_t *this = (directfb_driver_t *) this_gen;
 
-  (void)frame_gen;
-
   if (this->ovl_changed) {
 #ifdef DIRECTFB_X11
     if (this->xoverlay) {
@@ -756,7 +750,6 @@ static void directfb_display_frame (vo_driver_t *this_gen, vo_frame_t *frame_gen
   frame->locked = 1;
 }
 
-#ifndef DIRECTFB_X11
 /* directfb_display_frame2(): output to underlay */
 static void directfb_display_frame2 (vo_driver_t *this_gen, vo_frame_t *frame_gen) {
   directfb_driver_t       *this   = (directfb_driver_t *) this_gen;
@@ -882,7 +875,6 @@ static void directfb_display_frame2 (vo_driver_t *this_gen, vo_frame_t *frame_ge
                         (int  *)&frame->vo_frame.pitches[0]);
   frame->locked = 1;
 }
-#endif
 
 static int directfb_get_property (vo_driver_t *this_gen, int property) {
   directfb_driver_t *this = (directfb_driver_t *) this_gen;
@@ -946,18 +938,6 @@ static int directfb_set_property (vo_driver_t *this_gen,
   directfb_driver_t *this = (directfb_driver_t *) this_gen;
 
   switch (property) {
-
-    case VO_PROP_DISCARD_FRAMES:
-      if (value == -1) {
-        value = 0;
-        if (this->cur_frame) {
-          this->cur_frame->vo_frame.free (&this->cur_frame->vo_frame);
-          this->cur_frame = NULL;
-          value = 1;
-        }
-      }
-      break;
-
     case VO_PROP_INTERLACED:
       xprintf (this->xine, XINE_VERBOSITY_DEBUG,
                "video_out_directfb: deinterlacing set to %d.\n", value);
@@ -1199,8 +1179,6 @@ static int directfb_gui_data_exchange (vo_driver_t *this_gen,
 static void directfb_dispose (vo_driver_t *this_gen) {
   directfb_driver_t *this = (directfb_driver_t *) this_gen;
 
-  _x_vo_scale_cleanup (&this->sc, this->xine->config);
-
   if (this->cur_frame)
     this->cur_frame->vo_frame.dispose (&this->cur_frame->vo_frame);
 
@@ -1436,7 +1414,6 @@ static DFBEnumerationResult find_underlay (DFBDisplayLayerID id,
   return DFENUM_OK;
 }
 
-#if 0
 static DFBEnumerationResult find_subpicture (DFBDisplayLayerID id,
                                              DFBDisplayLayerDescription dsc, void *ctx) {
   DFBDisplayLayerID *ret_id = (DFBDisplayLayerID *) ctx;
@@ -1451,9 +1428,7 @@ static DFBEnumerationResult find_subpicture (DFBDisplayLayerID id,
 
   return DFENUM_OK;
 }
-#endif
 
-#ifndef DIRECTFB_X11
 static void init_subpicture (directfb_driver_t *this) {
   DFBResult ret;
 
@@ -1541,7 +1516,6 @@ static void init_subpicture (directfb_driver_t *this) {
            _("video_out_directfb: using hardware subpicture acceleration.\n"));
   }
 }
-#endif
 
 static DFBResult init_device (directfb_driver_t *this) {
   IDirectFBSurface           *surface;
@@ -1750,26 +1724,21 @@ static DFBResult init_device (directfb_driver_t *this) {
   return DFB_OK;
 }
 
-#ifndef DIRECTFB_X11
 static void directfb_frame_output_cb (void *user_data, int video_width, int video_height,
                                       double video_pixel_aspect, int *dest_x, int *dest_y,
                                       int *dest_width, int *dest_height,
                                       double *dest_pixel_aspect, int *win_x, int *win_y) {
   directfb_driver_t *this = (directfb_driver_t *) user_data;
 
-  (void)video_width;
-  (void)video_height;
-
   *dest_x            = 0;
   *dest_y            = 0;
   *dest_width        = this->screen_width;
   *dest_height       = this->screen_height;
-  *dest_pixel_aspect = (video_pixel_aspect > 0.01) ? video_pixel_aspect :
+  *dest_pixel_aspect = video_pixel_aspect ? :
                        (double)this->screen_width/(double)this->screen_height;
   *win_x             = 0;
   *win_y             = 0;
 }
-#endif
 
 /*** DirectFB plugin functions ***/
 
@@ -1787,14 +1756,13 @@ static inline int convert_caps (DFBDisplayLayerCapabilities caps)
   return vo;
 }
 
-#ifndef DIRECTFB_X11
 static vo_driver_t *open_plugin_fb (video_driver_class_t *class_gen, const void *visual_gen) {
   directfb_class_t  *class  = (directfb_class_t *) class_gen;
   directfb_driver_t *this;
-  const char        *args[] = { "xine", "--dfb:" DIRECTFB_OPTIONS };
+  char              *args[] = { "xine", "--dfb:" DIRECTFB_OPTIONS };
   int                argn   = 2;
   char             **argp   = (char **) args;
-  const fb_visual_t *visual = (const fb_visual_t *) visual_gen;
+  fb_visual_t       *visual = (fb_visual_t *) visual_gen;
   config_values_t   *config = class->xine->config;
   DFBDisplayLayerID  id;
   DFBResult          ret;
@@ -1828,7 +1796,7 @@ static vo_driver_t *open_plugin_fb (video_driver_class_t *class_gen, const void
                              _("video layer id (auto: -1)"),
                              _("Select the video output layer by its id."),
                              20, NULL, 0);
-  if (id == (DFBDisplayLayerID)-1) {
+  if (id == -1) {
     IDirectFBScreen *screen;
 
     /* retrieve an interface to the current screen */
@@ -1925,15 +1893,12 @@ static vo_driver_t *open_plugin_fb (video_driver_class_t *class_gen, const void
 
   return &this->vo_driver;
 }
-#endif
 
 #ifndef DIRECTFB_X11
-static void *init_class_fb (xine_t *xine, const void *visual_gen) {
+static void *init_class_fb (xine_t *xine, void *visual_gen) {
   directfb_class_t *this;
   const char       *error;
 
-  (void)visual_gen;
-
   /* check DirectFB version */
   error = DirectFBCheckVersion( DIRECTFB_MAJOR_VERSION,
                                 DIRECTFB_MINOR_VERSION,
@@ -1945,9 +1910,6 @@ static void *init_class_fb (xine_t *xine, const void *visual_gen) {
   }
 
   this = (directfb_class_t *) calloc(1, sizeof(directfb_class_t));
-  if (!this)
-    return NULL;
-
   this->driver_class.open_plugin     = open_plugin_fb;
   this->driver_class.identifier      = "DirectFB";
   this->driver_class.description     = N_("xine video output plugin using DirectFB.");
@@ -1959,8 +1921,8 @@ static void *init_class_fb (xine_t *xine, const void *visual_gen) {
 }
 
 static const vo_info_t vo_info_directfb_fb = {
-  .priority    = 8,
-  .visual_type = XINE_VISUAL_TYPE_FB,
+  8,                   /* priority    */
+  XINE_VISUAL_TYPE_FB  /* visual type */
 };
 
 /*** XDirectFB plugin functions ****/
@@ -1969,10 +1931,10 @@ static const vo_info_t vo_info_directfb_fb = {
 static vo_driver_t *open_plugin_x11 (video_driver_class_t *class_gen, const void *visual_gen) {
   directfb_class_t  *class  = (directfb_class_t *) class_gen;
   directfb_driver_t *this;
-  const char        *args[] = { "xine", "--dfb:" XDIRECTFB_OPTIONS };
+  char              *args[] = { "xine", "--dfb:" XDIRECTFB_OPTIONS };
   int                argn   = 2;
   char             **argp   = (char **) args;
-  const x11_visual_t *visual = (const x11_visual_t *) visual_gen;
+  x11_visual_t      *visual = (x11_visual_t *) visual_gen;
   XWindowAttributes  attrs;
   IDirectFBScreen   *screen;
   DFBDisplayLayerID  id     = DLID_PRIMARY;
@@ -2127,9 +2089,9 @@ static vo_driver_t *open_plugin_x11 (video_driver_class_t *class_gen, const void
   return &this->vo_driver;
 }
 
-static void *init_class_x11 (xine_t *xine, const void *visual_gen) {
+static void *init_class_x11 (xine_t *xine, void *visual_gen) {
   directfb_class_t *this;
-  const x11_visual_t *visual = (const x11_visual_t *) visual_gen;
+  x11_visual_t     *visual = (x11_visual_t *) visual_gen;
   const char       *error;
 
   /* check DirectFB version */
@@ -2153,8 +2115,6 @@ static void *init_class_x11 (xine_t *xine, const void *visual_gen) {
     return NULL;
 
   this = (directfb_class_t *) calloc(1, sizeof(directfb_class_t));
-  if (!this)
-    return NULL;
   this->driver_class.open_plugin     = open_plugin_x11;
   this->driver_class.identifier      = "XDirectFB";
   this->driver_class.description     = N_("xine video output plugin using DirectFB under XDirectFB.");
@@ -2166,7 +2126,7 @@ static void *init_class_x11 (xine_t *xine, const void *visual_gen) {
   return this;
 }
 
-static void *init_class_x11_2 (xine_t *xine, const void *visual_gen) {
+static void *init_class_x11_2 (xine_t *xine, void *visual_gen) {
   directfb_class_t *this;
 
   this = init_class_x11( xine, visual_gen );
@@ -2177,13 +2137,13 @@ static void *init_class_x11_2 (xine_t *xine, const void *visual_gen) {
 }
 
 static const vo_info_t vo_info_directfb_x11 = {
-  .priority    = 8,
-  .visual_type = XINE_VISUAL_TYPE_X11,
+  8,                    /* priority    */
+  XINE_VISUAL_TYPE_X11  /* visual type */
 };
 
 static const vo_info_t vo_info_directfb_x11_2 = {
-  .priority    = 8,
-  .visual_type = XINE_VISUAL_TYPE_X11_2,
+  8,                      /* priority    */
+  XINE_VISUAL_TYPE_X11_2  /* visual type */
 };
 #endif /* HAVE_X11 */
 
@@ -2200,6 +2160,6 @@ const plugin_info_t xine_plugin_info[] EXPORTED = {
   { PLUGIN_VIDEO_OUT, VIDEO_OUT_DRIVER_IFACE_VERSION, "XDirectFB",
     XINE_VERSION_CODE, &vo_info_directfb_x11_2, init_class_x11_2 },
 #endif
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
