@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2019 the xine project
+ * Copyright (C) 2000-2014 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -30,7 +30,6 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
-#include <pthread.h>
 
 #include "xine.h"
 
@@ -41,58 +40,55 @@
 
 typedef struct {
   vo_frame_t           vo_frame;
-  unsigned int         width;
-  unsigned int         height;
+  int                  width;
+  int                  height;
   double               ratio;
   int                  format;
-} vo_none_frame_t;
+  xine_t               *xine;
+} none_frame_t;
 
 typedef struct {
   vo_driver_t          vo_driver;
+  config_values_t     *config;
   int                  ratio;
   xine_t               *xine;
-} vo_none_driver_t;
+} none_driver_t;
 
 typedef struct {
   video_driver_class_t  driver_class;
+  config_values_t      *config;
   xine_t               *xine;
-} vo_none_class_t;
+} none_class_t;
 
 
-static void vo_none_free_framedata(vo_none_frame_t* frame) {
+static void free_framedata(none_frame_t* frame) {
   if(frame->vo_frame.base[0]) {
-    xine_free_aligned(frame->vo_frame.base[0]);
+    free(frame->vo_frame.base[0]);
     frame->vo_frame.base[0] = NULL;
     frame->vo_frame.base[1] = NULL;
     frame->vo_frame.base[2] = NULL;
   }
 }
 
-static void vo_none_frame_dispose(vo_frame_t *vo_frame) {
-  vo_none_frame_t *frame = (vo_none_frame_t *)vo_frame;
-  vo_none_free_framedata(frame);
-  pthread_mutex_destroy (&frame->vo_frame.mutex);
+static void none_frame_dispose(vo_frame_t *vo_frame) {
+  none_frame_t *frame = (none_frame_t *)vo_frame;
+  free_framedata(frame);
   free (frame);
 }
 
-static void vo_none_frame_field(vo_frame_t *vo_frame, int which_field) {
+static void none_frame_field(vo_frame_t *vo_frame, int which_field) {
   /* do nothing */
-  (void)vo_frame;
-  (void)which_field;
 }
 
-static uint32_t vo_none_get_capabilities(vo_driver_t *vo_driver) {
-  /* No, we dont crop. Neither do we interpret color matrix or range. */
-  /* But we also dont ask decoders to convert data just for the trash ;-) */
-  (void)vo_driver;
-  return VO_CAP_YV12 | VO_CAP_YUY2 | VO_CAP_CROP | VO_CAP_COLOR_MATRIX | VO_CAP_FULLRANGE;
+static uint32_t none_get_capabilities(vo_driver_t *vo_driver) {
+  return VO_CAP_YV12 | VO_CAP_YUY2;
 }
 
-static vo_frame_t *vo_none_alloc_frame(vo_driver_t *vo_driver) {
+static vo_frame_t *none_alloc_frame(vo_driver_t *vo_driver) {
   /* none_driver_t *this = (none_driver_t *) vo_driver; */
-  vo_none_frame_t  *frame;
+  none_frame_t  *frame;
 
-  frame = calloc(1, sizeof(vo_none_frame_t));
+  frame = calloc(1, sizeof(none_frame_t));
   if(!frame)
     return NULL;
 
@@ -104,23 +100,22 @@ static vo_frame_t *vo_none_alloc_frame(vo_driver_t *vo_driver) {
 
   frame->vo_frame.proc_slice = NULL;
   frame->vo_frame.proc_frame = NULL;
-  frame->vo_frame.field      = vo_none_frame_field;
-  frame->vo_frame.dispose    = vo_none_frame_dispose;
+  frame->vo_frame.field      = none_frame_field;
+  frame->vo_frame.dispose    = none_frame_dispose;
   frame->vo_frame.driver     = vo_driver;
 
   return (vo_frame_t *)frame;
 }
 
-static void vo_none_update_frame_format(vo_driver_t *vo_driver, vo_frame_t *vo_frame,
+static void none_update_frame_format(vo_driver_t *vo_driver, vo_frame_t *vo_frame,
 				     uint32_t width, uint32_t height,
 				     double ratio, int format, int flags) {
-  vo_none_driver_t *this = (vo_none_driver_t *) vo_driver;
-  vo_none_frame_t  *frame = (vo_none_frame_t *) vo_frame;
+  none_driver_t *this = (none_driver_t *) vo_driver;
+  none_frame_t  *frame = (none_frame_t *) vo_frame;
 
-  (void)flags;
   if((frame->width != width) || (frame->height != height) || (frame->format != format)) {
 
-    vo_none_free_framedata(frame);
+    free_framedata(frame);
 
     frame->width  = width;
     frame->height = height;
@@ -139,7 +134,7 @@ static void vo_none_update_frame_format(vo_driver_t *vo_driver, vo_frame_t *vo_f
 	y_size  = frame->vo_frame.pitches[0] * height;
 	uv_size = frame->vo_frame.pitches[1] * ((height+1)/2);
 
-	frame->vo_frame.base[0] = xine_malloc_aligned (y_size + 2*uv_size);
+	frame->vo_frame.base[0] = malloc (y_size + 2*uv_size);
         if (frame->vo_frame.base[0]) {
           frame->vo_frame.base[1] = frame->vo_frame.base[0] + y_size;
           frame->vo_frame.base[2] = frame->vo_frame.base[0] + y_size + uv_size;
@@ -156,7 +151,7 @@ static void vo_none_update_frame_format(vo_driver_t *vo_driver, vo_frame_t *vo_f
 
     case XINE_IMGFMT_YUY2:
       frame->vo_frame.pitches[0] = 8*((width + 3) / 4);
-      frame->vo_frame.base[0] = xine_malloc_aligned(frame->vo_frame.pitches[0] * height);
+      frame->vo_frame.base[0] = malloc(frame->vo_frame.pitches[0] * height);
       frame->vo_frame.base[1] = NULL;
       frame->vo_frame.base[2] = NULL;
       if (!frame->vo_frame.base[0]) {
@@ -169,24 +164,23 @@ static void vo_none_update_frame_format(vo_driver_t *vo_driver, vo_frame_t *vo_f
 
     default:
       xprintf (this->xine, XINE_VERBOSITY_DEBUG, "video_out_none: unknown frame format %04x)\n", format);
-      frame->width = 0;
-      frame->vo_frame.width = 0;
       break;
+
     }
   }
 
   frame->ratio = ratio;
 }
 
-static void vo_none_display_frame(vo_driver_t *vo_driver, vo_frame_t *vo_frame) {
-  /* vo_none_driver_t  *driver = (vo_none_driver_t *)vo_driver; */
+static void none_display_frame(vo_driver_t *vo_driver, vo_frame_t *vo_frame) {
+  /* none_driver_t  *driver = (none_driver_t *)vo_driver; */
+  none_frame_t   *frame = (none_frame_t *)vo_frame;
 
-  (void)vo_driver;
-  vo_frame->free(vo_frame);
+  frame->vo_frame.free(&frame->vo_frame);
 }
 
-static int vo_none_get_property(vo_driver_t *vo_driver, int property) {
-  vo_none_driver_t  *driver = (vo_none_driver_t *)vo_driver;
+static int none_get_property(vo_driver_t *vo_driver, int property) {
+  none_driver_t  *driver = (none_driver_t *)vo_driver;
 
   switch(property) {
 
@@ -201,8 +195,8 @@ static int vo_none_get_property(vo_driver_t *vo_driver, int property) {
   return 0;
 }
 
-static int vo_none_set_property(vo_driver_t *vo_driver, int property, int value) {
-  vo_none_driver_t  *driver = (vo_none_driver_t *)vo_driver;
+static int none_set_property(vo_driver_t *vo_driver, int property, int value) {
+  none_driver_t  *driver = (none_driver_t *)vo_driver;
 
   switch(property) {
 
@@ -219,19 +213,15 @@ static int vo_none_set_property(vo_driver_t *vo_driver, int property, int value)
   return value;
 }
 
-static void vo_none_get_property_min_max(vo_driver_t *vo_driver,
+static void none_get_property_min_max(vo_driver_t *vo_driver,
 				      int property, int *min, int *max) {
-  (void)vo_driver;
-  (void)property;
   *min = 0;
   *max = 0;
 }
 
-static int vo_none_gui_data_exchange(vo_driver_t *vo_driver, int data_type, void *data) {
-/*   vo_none_driver_t     *this = (vo_none_driver_t *) vo_driver; */
+static int none_gui_data_exchange(vo_driver_t *vo_driver, int data_type, void *data) {
+/*   none_driver_t     *this = (none_driver_t *) vo_driver; */
 
-  (void)vo_driver;
-  (void)data;
   switch (data_type) {
   case XINE_GUI_SEND_COMPLETION_EVENT:
   case XINE_GUI_SEND_DRAWABLE_CHANGED:
@@ -244,42 +234,39 @@ static int vo_none_gui_data_exchange(vo_driver_t *vo_driver, int data_type, void
 
   return 0;
 }
-static void vo_none_dispose(vo_driver_t *vo_driver) {
-  vo_none_driver_t *this = (vo_none_driver_t *) vo_driver;
+static void none_dispose(vo_driver_t *vo_driver) {
+  none_driver_t *this = (none_driver_t *) vo_driver;
 
   free(this);
 }
 
-static int vo_none_redraw_needed(vo_driver_t *vo_driver) {
-  (void)vo_driver;
+static int none_redraw_needed(vo_driver_t *vo_driver) {
   return 0;
 }
 
-static vo_driver_t *vo_none_open_plugin(video_driver_class_t *driver_class, const void *visual) {
-  vo_none_class_t    *class = (vo_none_class_t *) driver_class;
-  vo_none_driver_t   *driver;
+static vo_driver_t *open_plugin(video_driver_class_t *driver_class, const void *visual) {
+  none_class_t    *class = (none_class_t *) driver_class;
+  none_driver_t   *driver;
 
-  (void)visual;
-  driver = calloc(1, sizeof(vo_none_driver_t));
-  if (!driver)
-    return NULL;
+  driver = calloc(1, sizeof(none_driver_t));
 
+  driver->config = class->config;
   driver->xine   = class->xine;
   driver->ratio  = XINE_VO_ASPECT_AUTO;
 
-  driver->vo_driver.get_capabilities     = vo_none_get_capabilities;
-  driver->vo_driver.alloc_frame          = vo_none_alloc_frame ;
-  driver->vo_driver.update_frame_format  = vo_none_update_frame_format;
+  driver->vo_driver.get_capabilities     = none_get_capabilities;
+  driver->vo_driver.alloc_frame          = none_alloc_frame ;
+  driver->vo_driver.update_frame_format  = none_update_frame_format;
   driver->vo_driver.overlay_begin        = NULL;
   driver->vo_driver.overlay_blend        = NULL;
   driver->vo_driver.overlay_end          = NULL;
-  driver->vo_driver.display_frame        = vo_none_display_frame;
-  driver->vo_driver.get_property         = vo_none_get_property;
-  driver->vo_driver.set_property         = vo_none_set_property;
-  driver->vo_driver.get_property_min_max = vo_none_get_property_min_max;
-  driver->vo_driver.gui_data_exchange    = vo_none_gui_data_exchange;
-  driver->vo_driver.dispose              = vo_none_dispose;
-  driver->vo_driver.redraw_needed        = vo_none_redraw_needed;
+  driver->vo_driver.display_frame        = none_display_frame;
+  driver->vo_driver.get_property         = none_get_property;
+  driver->vo_driver.set_property         = none_set_property;
+  driver->vo_driver.get_property_min_max = none_get_property_min_max;
+  driver->vo_driver.gui_data_exchange    = none_gui_data_exchange;
+  driver->vo_driver.dispose              = none_dispose;
+  driver->vo_driver.redraw_needed        = none_redraw_needed;
 
   return &driver->vo_driver;
 }
@@ -287,37 +274,29 @@ static vo_driver_t *vo_none_open_plugin(video_driver_class_t *driver_class, cons
 /*
  * Class related functions.
  */
-static void *vo_none_init_class (xine_t *xine, const void *visual) {
-  vo_none_class_t        *this;
+static void *init_class (xine_t *xine, void *visual) {
+  none_class_t        *this;
 
-  (void)visual;
-  this = calloc(1, sizeof(vo_none_class_t));
-  if (!this)
-    return NULL;
+  this = calloc(1, sizeof(none_class_t));
 
-  this->driver_class.open_plugin     = vo_none_open_plugin;
+  this->driver_class.open_plugin     = open_plugin;
   this->driver_class.identifier      = "none";
   this->driver_class.description     = N_("xine video output plugin which displays nothing");
   this->driver_class.dispose         = default_video_driver_class_dispose;
 
+  this->config                       = xine->config;
   this->xine                         = xine;
 
   return this;
 }
 
 static const vo_info_t vo_info_none = {
-  .priority    = 5,
-  .visual_type = XINE_VISUAL_TYPE_NONE,
+  5,                        /* Priority    */
+  XINE_VISUAL_TYPE_NONE     /* Visual type */
 };
 
-#define VO_NONE_CATALOG { PLUGIN_VIDEO_OUT, 22, "none", XINE_VERSION_CODE, &vo_info_none, vo_none_init_class }
-
-#ifndef XINE_MAKE_BUILTINS
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
-  VO_NONE_CATALOG,
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_VIDEO_OUT, 22, "none", XINE_VERSION_CODE, &vo_info_none, init_class },
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
-#endif
-
-
