@@ -1,6 +1,6 @@
 
 /*
- * Copyright (C) 2007-2018 the xine project
+ * Copyright (C) 2007-2014 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -55,7 +55,11 @@
 #include "yuv2rgb.h"
 #include <xine/xineutils.h>
 
-
+#ifdef HAVE_FFMPEG_AVUTIL_H
+#  include <mem.h>
+#else
+#  include <libavutil/mem.h>
+#endif
 
 typedef struct {
   vo_frame_t         vo_frame;
@@ -120,7 +124,6 @@ static void raw_overlay_begin (vo_driver_t *this_gen, vo_frame_t *frame_gen, int
 {
   raw_driver_t  *this = (raw_driver_t *) this_gen;
 
-  (void)frame_gen;
   if ( !changed )
 	return;
 
@@ -132,7 +135,6 @@ static void raw_overlay_blend (vo_driver_t *this_gen, vo_frame_t *frame_gen, vo_
 {
   raw_driver_t  *this = (raw_driver_t *) this_gen;
 
-  (void)frame_gen;
   if ( !this->ovl_changed || this->ovl_changed>XINE_VORAW_MAX_OVL )
     return;
 
@@ -149,7 +151,6 @@ static void raw_overlay_end (vo_driver_t *this_gen, vo_frame_t *vo_img)
 {
   raw_driver_t  *this = (raw_driver_t *) this_gen;
 
-  (void)vo_img;
   if ( !this->ovl_changed )
     return;
 
@@ -219,10 +220,10 @@ static void raw_frame_dispose (vo_frame_t *vo_img)
 
   frame->yuv2rgb->dispose (frame->yuv2rgb);
 
-  xine_free_aligned (frame->vo_frame.base[0]);
-  xine_free_aligned (frame->vo_frame.base[1]);
-  xine_free_aligned (frame->vo_frame.base[2]);
-  xine_free_aligned (frame->rgb);
+  av_free (frame->vo_frame.base[0]);
+  av_free (frame->vo_frame.base[1]);
+  av_free (frame->vo_frame.base[2]);
+  av_free (frame->rgb);
   free (frame);
 }
 
@@ -238,15 +239,6 @@ static vo_frame_t *raw_alloc_frame (vo_driver_t *this_gen)
   if (!frame)
     return NULL;
 
-  /*
-   * colorspace converter for this frame
-   */
-  frame->yuv2rgb = this->yuv2rgb_factory->create_converter (this->yuv2rgb_factory);
-  if (!frame->yuv2rgb) {
-    free(frame);
-    return NULL;
-  }
-
   frame->vo_frame.base[0] = frame->vo_frame.base[1] = frame->vo_frame.base[2] = frame->rgb = NULL;
   frame->width = frame->height = frame->format = frame->flags = 0;
 
@@ -261,6 +253,11 @@ static vo_frame_t *raw_alloc_frame (vo_driver_t *this_gen)
   frame->vo_frame.dispose    = raw_frame_dispose;
   frame->vo_frame.driver     = this_gen;
 
+  /*
+   * colorspace converter for this frame
+   */
+  frame->yuv2rgb = this->yuv2rgb_factory->create_converter (this->yuv2rgb_factory);
+
   return (vo_frame_t *) frame;
 }
 
@@ -271,34 +268,33 @@ static void raw_update_frame_format (vo_driver_t *this_gen, vo_frame_t *frame_ge
 {
   raw_frame_t   *frame = (raw_frame_t *) frame_gen;
 
-  (void)this_gen;
   /* Check frame size and format and reallocate if necessary */
-  if ((frame->width != (int)width)
-      || (frame->height != (int)height)
+  if ((frame->width != width)
+      || (frame->height != height)
       || (frame->format != format)
       || (frame->flags  != flags)) {
 /*     lprintf ("updating frame to %d x %d (ratio=%g, format=%08x)\n", width, height, ratio, format); */
 
     /* (re-) allocate render space */
-    xine_free_aligned (frame->vo_frame.base[0]);
-    xine_free_aligned (frame->vo_frame.base[1]);
-    xine_free_aligned (frame->vo_frame.base[2]);
-    xine_free_aligned (frame->rgb);
+    av_free (frame->vo_frame.base[0]);
+    av_free (frame->vo_frame.base[1]);
+    av_free (frame->vo_frame.base[2]);
+    av_free (frame->rgb);
 
     if (format == XINE_IMGFMT_YV12) {
       frame->vo_frame.pitches[0] = 8*((width + 7) / 8);
       frame->vo_frame.pitches[1] = 8*((width + 15) / 16);
       frame->vo_frame.pitches[2] = 8*((width + 15) / 16);
-      frame->vo_frame.base[0] = xine_mallocz_aligned (frame->vo_frame.pitches[0] * height);
-      frame->vo_frame.base[1] = xine_mallocz_aligned (frame->vo_frame.pitches[1] * ((height+1)/2));
-      frame->vo_frame.base[2] = xine_mallocz_aligned (frame->vo_frame.pitches[2] * ((height+1)/2));
+      frame->vo_frame.base[0] = av_mallocz (frame->vo_frame.pitches[0] * height);
+      frame->vo_frame.base[1] = av_mallocz (frame->vo_frame.pitches[1] * ((height+1)/2));
+      frame->vo_frame.base[2] = av_mallocz (frame->vo_frame.pitches[2] * ((height+1)/2));
     } else {
       frame->vo_frame.pitches[0] = 8*((width + 3) / 4);
-      frame->vo_frame.base[0] = xine_mallocz_aligned (frame->vo_frame.pitches[0] * height);
+      frame->vo_frame.base[0] = av_mallocz (frame->vo_frame.pitches[0] * height);
       frame->vo_frame.base[1] = NULL;
       frame->vo_frame.base[2] = NULL;
     }
-    frame->rgb = xine_mallocz_aligned (BYTES_PER_PIXEL*width*height);
+    frame->rgb = av_mallocz (BYTES_PER_PIXEL*width*height);
 
     /* set up colorspace converter */
     switch (flags & VO_BOTH_FIELDS) {
@@ -340,7 +336,6 @@ static void raw_update_frame_format (vo_driver_t *this_gen, vo_frame_t *frame_ge
 
 static int raw_redraw_needed (vo_driver_t *this_gen)
 {
-  (void)this_gen;
   return 0;
 }
 
@@ -375,7 +370,6 @@ static void raw_display_frame (vo_driver_t *this_gen, vo_frame_t *frame_gen)
 
 static int raw_get_property (vo_driver_t *this_gen, int property)
 {
-  (void)this_gen;
   switch (property) {
   case VO_PROP_ASPECT_RATIO:
     return XINE_VO_ASPECT_AUTO;
@@ -400,22 +394,6 @@ static int raw_get_property (vo_driver_t *this_gen, int property)
 
 static int raw_set_property (vo_driver_t *this_gen, int property, int value)
 {
-  raw_driver_t *this = (raw_driver_t *) this_gen;
-
-  if (property == VO_PROP_DISCARD_FRAMES) {
-    if (value == -1) {
-      int i, n = 0;
-      for (i = NUM_FRAMES_BACKLOG - 1; i >= 0; i--) {
-        if (this->frame[i]) {
-          this->frame[i]->vo_frame.free (&this->frame[i]->vo_frame);
-          this->frame[i] = NULL;
-          n++;
-        }
-      }
-      value = n;
-    }
-  }
-
   return value;
 }
 
@@ -423,8 +401,6 @@ static int raw_set_property (vo_driver_t *this_gen, int property, int value)
 
 static void raw_get_property_min_max (vo_driver_t *this_gen, int property, int *min, int *max)
 {
-  (void)this_gen;
-  (void)property;
   *min = 0;
   *max = 0;
 }
@@ -433,9 +409,6 @@ static void raw_get_property_min_max (vo_driver_t *this_gen, int property, int *
 
 static int raw_gui_data_exchange (vo_driver_t *this_gen, int data_type, void *data)
 {
-  (void)this_gen;
-  (void)data_type;
-  (void)data;
   return 0;
 }
 
@@ -444,7 +417,6 @@ static int raw_gui_data_exchange (vo_driver_t *this_gen, int data_type, void *da
 static uint32_t raw_get_capabilities (vo_driver_t *this_gen)
 {
   uint32_t capabilities = VO_CAP_YV12 | VO_CAP_YUY2 | VO_CAP_CROP;
-  (void)this_gen;
   return capabilities;
 }
 
@@ -470,9 +442,9 @@ static void raw_dispose (vo_driver_t *this_gen)
 
 
 static vo_driver_t *raw_open_plugin (video_driver_class_t *class_gen, const void *visual_gen)
-{ 
-  const raw_visual_t *visual  = (const raw_visual_t *) visual_gen;
+{
   raw_class_t       *class   = (raw_class_t *) class_gen;
+  raw_visual_t         *visual  = (raw_visual_t *) visual_gen;
   raw_driver_t      *this;
   int i;
 
@@ -503,11 +475,6 @@ static vo_driver_t *raw_open_plugin (video_driver_class_t *class_gen, const void
   this->vo_driver.redraw_needed        = raw_redraw_needed;
 
   this->yuv2rgb_factory = yuv2rgb_factory_init (MODE_24_BGR, 1, NULL); /* converts to rgb */
-  if (!this->yuv2rgb_factory) {
-    xprintf (this->xine, XINE_VERBOSITY_LOG, LOG_MODULE ": yuv2rgb initialization failed\n");
-    free(this);
-    return NULL;
-  }
 
   for (i = 0; i < NUM_FRAMES_BACKLOG; i++)
     this->frame[i] = 0;
@@ -526,15 +493,9 @@ static vo_driver_t *raw_open_plugin (video_driver_class_t *class_gen, const void
  * class functions
  */
 
-static void *raw_init_class (xine_t *xine, const void *visual_gen)
+static void *raw_init_class (xine_t *xine, void *visual_gen)
 {
-  raw_class_t *this;
-
-  (void)visual_gen;
-
-  this = calloc(1, sizeof(*this));
-  if (!this)
-    return NULL;
+  raw_class_t *this = (raw_class_t *) calloc(1, sizeof(raw_class_t));
 
   this->driver_class.open_plugin     = raw_open_plugin;
   this->driver_class.identifier      = "raw";
@@ -548,8 +509,8 @@ static void *raw_init_class (xine_t *xine, const void *visual_gen)
 
 
 static const vo_info_t vo_info_raw = {
-  .priority    = 7,
-  .visual_type = XINE_VISUAL_TYPE_RAW,
+  7,                    /* priority    */
+  XINE_VISUAL_TYPE_RAW  /* visual type */
 };
 
 
@@ -560,5 +521,5 @@ static const vo_info_t vo_info_raw = {
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_VIDEO_OUT, 22, "raw", XINE_VERSION_CODE, &vo_info_raw, raw_init_class },
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
