@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2019 the xine project
+ * Copyright (C) 2000-2012 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -39,8 +39,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#include <unistd.h>
-#include <pthread.h>
+#include <assert.h>
 
 #if defined(__FreeBSD__)
 #include <machine/param.h>
@@ -217,6 +216,7 @@ typedef struct {
   video_driver_class_t driver_class;
 
   Display             *display;
+  config_values_t     *config;
   XvPortID             xv_port;
   XvAdaptorInfo       *adaptor_info;
   unsigned int         adaptor_num;
@@ -457,8 +457,6 @@ static uint32_t xvmc_get_capabilities (vo_driver_t *this_gen) {
 
 static void xvmc_frame_field (vo_frame_t *vo_img, int which_field) {
   lprintf ("xvmc_frame_field\n");
-  (void)vo_img;
-  (void)which_field;
 }
 
 static void xvmc_frame_dispose (vo_frame_t *vo_img) {
@@ -488,10 +486,10 @@ static void xvmc_render_macro_blocks(vo_frame_t *current_image,
   int           flags;
 
   lprintf ("xvmc_render_macro_blocks\n");
-  lprintf ("slices %d %p %p %p\n",
+  lprintf ("slices %d 0x%08lx 0x%08lx 0x%08lx\n",
 	   macroblocks->slices,
-           (void *) current_frame, (void *) backward_frame,
-           (void *) forward_frame);
+	   (long) current_frame, (long) backward_frame,
+	   (long) forward_frame);
   /* lprintf ("slices %d 0x%08lx 0x%08lx 0x%08lx\n",macroblocks->slices,
 	   (long) current_frame->surface, (long) backward_frame->surface,
 	   (long) forward_frame->surface);
@@ -589,19 +587,18 @@ static cxid_t *xvmc_set_context (xvmc_driver_t *this,
 
   lprintf ("xvmc_set_context %dx%d %04x\n",width,height,format);
 
-  (void)ratio;
   /* initialize block & macro block pointers first time */
   if(macroblocks->blocks == NULL ||  macroblocks->macro_blocks == NULL) {
     macroblocks->blocks       = calloc(1, sizeof(XvMCBlockArray));
     macroblocks->macro_blocks = calloc(1, sizeof(XvMCMacroBlockArray));
 
-    lprintf("macroblocks->blocks %p ->macro_blocks %p\n",
-            (void *)macroblocks->blocks, (void *)macroblocks->macro_blocks);
+    lprintf("macroblocks->blocks %lx ->macro_blocks %lx\n",
+	    macroblocks->blocks,macroblocks->macro_blocks);
   }
 
   if((this->context_id.xid != NULL)   &&
-     ((int)width  == this->surface_width)  &&
-     ((int)height == this->surface_height) &&
+     (width  == this->surface_width)  &&
+     (height == this->surface_height) &&
      (format == this->surface_format) &&
      (flags  == this->surface_flags)) {
 
@@ -765,14 +762,13 @@ static void xvmc_update_frame_format (vo_driver_t *this_gen,
 
   if (format != XINE_IMGFMT_XVMC) {
     xprintf (this->xine, XINE_VERBOSITY_LOG, "xvmc_update_frame_format: frame format %08x not supported\n", format);
-    frame->vo_frame.width = frame->width = 0;
-    return;
+    _x_abort();
   }
 
   lprintf ("xvmc_update_frame_format\n");
 
-  if ((frame->width != (int)width)
-      || (frame->height != (int)height)
+  if ((frame->width != width)
+      || (frame->height != height)
       || (frame->format != format)) {
 
     lprintf ("updating frame to %d x %d (ratio=%f, format=%08x)\n",
@@ -877,18 +873,21 @@ static void xvmc_add_recent_frame (xvmc_driver_t *this, xvmc_frame_t *frame) {
   this->recent_frames[0] = frame;
 }
 
-static int xv_flush_recent_frames (xvmc_driver_t *this) {
-  int i, n = 0;
+/* currently not used - we could have a method to call this from video loop */
+#if 0
+static void xvmc_flush_recent_frames (xvmc_driver_t *this) {
+  int i;
 
-  for (i = 0; i < VO_NUM_RECENT_FRAMES; i++) {
-    if (this->recent_frames[i]) {
-      this->recent_frames[i]->vo_frame.free (&this->recent_frames[i]->vo_frame);
-      this->recent_frames[i] = NULL;
-      n++;
-    }
+  lprintf ("xvmc_flush_recent_frames\n");
+
+  for( i=0; i < VO_NUM_RECENT_FRAMES; i++ ) {
+    if( this->recent_frames[i] )
+      this->recent_frames[i]->vo_frame.free
+	(&this->recent_frames[i]->vo_frame);
+    this->recent_frames[i] = NULL;
   }
-  return n;
 }
+#endif
 
 static int xvmc_redraw_needed (vo_driver_t *this_gen) {
   xvmc_driver_t  *this = (xvmc_driver_t *) this_gen;
@@ -923,7 +922,7 @@ static void xvmc_display_frame (vo_driver_t *this_gen, vo_frame_t *frame_gen) {
   xvmc_driver_t  *this  = (xvmc_driver_t *) this_gen;
   xvmc_frame_t   *frame = (xvmc_frame_t *) frame_gen;
 
-  lprintf ("xvmc_display_frame %d %p\n", frame_gen->id, (void *)frame_gen);
+  lprintf ("xvmc_display_frame %d %x\n",frame_gen->id,frame_gen);
 
   /*
    * queue frames (deinterlacing)
@@ -1058,11 +1057,6 @@ static int xvmc_set_property (vo_driver_t *this_gen,
   }
   else {
     switch (property) {
-    case VO_PROP_DISCARD_FRAMES:
-      if (value == -1)
-        value = xv_flush_recent_frames (this);
-      break;
-
     case VO_PROP_ASPECT_RATIO:
       if (value>=XINE_VO_ASPECT_NUM_RATIOS)
 	value = XINE_VO_ASPECT_AUTO;
@@ -1239,7 +1233,6 @@ static void xvmc_dispose (vo_driver_t *this_gen) {
   }
 
   _x_alphablend_free(&this->alphablend_extra_data);
-  _x_vo_scale_cleanup (&this->sc, this->xine->config);
 
   free (this);
 }
@@ -1254,7 +1247,6 @@ static void xvmc_check_capability (xvmc_driver_t *this,
   cfg_entry_t *entry;
   const char  *str_prop = attr.name;
 
-  (void)base_id;
   /*
    * some Xv drivers (Gatos ATI) report some ~0 as max values, this is confusing.
    */
@@ -1318,14 +1310,14 @@ static void xvmc_update_XV_DOUBLE_BUFFER(void *this_gen, xine_cfg_entry_t *entry
 
 static vo_driver_t *open_plugin (video_driver_class_t *class_gen, const void *visual_gen) {
   xvmc_class_t         *class   = (xvmc_class_t *) class_gen;
-  config_values_t      *config  = class->xine->config;
+  config_values_t      *config  = class->config;
   xvmc_driver_t        *this    = NULL;
   unsigned int          i, formats;
   XvPortID              xv_port = class->xv_port;
   XvAttribute          *attr;
   XvImageFormatValues  *fo;
   int                   nattr;
-  const x11_visual_t   *visual  = (const x11_visual_t *) visual_gen;
+  x11_visual_t         *visual  = (x11_visual_t *) visual_gen;
   XColor                dummy;
   XvAdaptorInfo        *adaptor_info = class->adaptor_info;
   unsigned int          adaptor_num  = class->adaptor_num;
@@ -1546,8 +1538,8 @@ static void dispose_class (video_driver_class_t *this_gen) {
   free (this);
 }
 
-static void *init_class (xine_t *xine, const void *visual_gen) {
-  const x11_visual_t *visual = (const x11_visual_t *) visual_gen;
+static void *init_class (xine_t *xine, void *visual_gen) {
+  x11_visual_t      *visual = (x11_visual_t *) visual_gen;
   xvmc_class_t      *this;
   Display           *display = NULL;
   unsigned int       adaptors, j = 0;
@@ -1713,6 +1705,7 @@ static void *init_class (xine_t *xine, const void *visual_gen) {
   this->driver_class.dispose         = dispose_class;
 
   this->display                      = display;
+  this->config                       = xine->config;
   this->xv_port                      = xv_port;
   this->adaptor_info                 = adaptor_info;
   this->adaptor_num                  = adaptor_num;
@@ -1730,8 +1723,8 @@ static void *init_class (xine_t *xine, const void *visual_gen) {
 
 static const vo_info_t vo_info_xvmc = {
   /* priority must be low until it supports displaying non-accelerated stuff */
-  .priority    = 0,
-  .visual_type = XINE_VISUAL_TYPE_X11,
+  0,                    /* priority    */
+  XINE_VISUAL_TYPE_X11  /* visual type */
 };
 
 /*
@@ -1741,7 +1734,7 @@ static const vo_info_t vo_info_xvmc = {
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_VIDEO_OUT, 22, "xvmc", XINE_VERSION_CODE, &vo_info_xvmc, init_class },
-  { PLUGIN_NONE, 0, NULL, 0, NULL, NULL }
+  { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
 #endif
